.. currentmodule:: pyhomogenize

Basic functions to read an write netCDF files
---------------------------------------------

.. autoclass:: netcdf_basics

   .. automethod:: __init__

   .. rubric:: Methods

   .. autosummary::

      netcdf_basics.open

      netcdf_basics.write

      netcdf_basics.get_var_name

      netcdf_basics.to_global_attributes

      netcdf_basics.to_variable_attributes

   .. rubric:: Attributes

   .. autosummary::

      netcdf_basics.files

      netcdf_basics.ds

      netcdf_basics.name
